@@ -1,5 +1,5 @@
-from .encoderPy import enscrypt, decrypt
+from .encoderPy import ENS, DEC
 
 __author__ = 'AlmazCode'
-__version__ = '1.0.2'
+__version__ = '1.0.3'
 __email__ = 'diamondplay43@gmail.com'
\ No newline at end of file
